@@ -34,8 +34,6 @@ def sync_algorithm(
     id: Optional[str]=None,
     name: Optional[str]=None,
     dir_path: Optional[Union[str, Path]]=None,
-    entrypoint_training: Optional[str]=None,
-    output_training: Optional[str]=None,
     mirror_name: Optional[str]="QUICKSTART",
     uploader: Optional[ResourceUploader]=None,
     polling: Union[float, int]=5,
@@ -45,16 +43,12 @@ def sync_algorithm(
     if id:
         return _sync_remote_algorithm(
             id=id,
-            entrypoint_training=entrypoint_training,
-            output_training=output_training,
             image_name=mirror_name,
         )
     else:
         return _sync_local_algorithm(
             name=name,
             dir_path=dir_path,
-            entrypoint_training=entrypoint_training,
-            output_training=output_training,
             image_name=mirror_name,
             uploader=uploader,
             polling=polling,
@@ -65,16 +59,10 @@ def sync_algorithm(
 
 def _sync_remote_algorithm(
     id: str,
-    entrypoint_training: Optional[str]=None,
-    output_training: Optional[str]=None,
     image_name: Optional[str]='QUICKSTART',
 ) -> Tuple[Algorithm, Optional[str]]:
     algo = Algorithm(id=id, load_detail=True)
     algo.mirror_id =_get_quickstart_mirror(image_name).id
-    if entrypoint_training is not None:
-        algo.entrypoint_training = entrypoint_training
-    if output_training is not None:
-        algo.output_training = output_training
     algo.save()
     algo.get_detail()
     return algo, None
@@ -83,8 +71,6 @@ def _sync_remote_algorithm(
 def _sync_local_algorithm(
     name: str,
     dir_path: Union[str, Path],
-    entrypoint_training: str,
-    output_training: str,
     image_name: str="QUICKSTART",
     uploader: Optional[ResourceUploader]=None,
     polling: Union[float, int]=5,
@@ -92,11 +78,11 @@ def _sync_local_algorithm(
     commit_msg: str=None,
 ) -> Tuple[Algorithm, Optional[str]]:
     # Required params
-    if not all([dir_path, entrypoint_training, output_training]):
+    if not dir_path:
         raise AnyLearnMissingParamException((
             "Parameters "
-            "`dir_path`, `entrypoint_training` and `output_training` "
-            "are required"
+            "`dir_path`"
+            "is required"
         ))
     if not name:
         name = make_name_by_path(dir_path)
@@ -104,8 +90,6 @@ def _sync_local_algorithm(
     algo = _get_or_create_algorithm(
         name=name,
         dir_path=dir_path,
-        entrypoint_training=entrypoint_training,
-        output_training=output_training,
         image_name=image_name,
     )
     if AnylearnConfig.git_ready and algo.git_address:
@@ -147,8 +131,6 @@ def _check_local_algorithm(dir_path: str) -> None:
 
 def _get_or_create_algorithm(name: str,
                              dir_path: Union[str, Path],
-                             entrypoint_training: str,
-                             output_training: str,
                              image_name: str="QUICKSTART") -> Algorithm:
     # Algo name or dir name
     if not name:
@@ -165,8 +147,6 @@ def _get_or_create_algorithm(name: str,
         algo =_create_new_algorithm(name)
     # Set execution metadata
     algo.mirror_id = image.id
-    algo.entrypoint_training = entrypoint_training
-    algo.output_training = output_training
     # Existing/new algo needs respectively create/update towards remote
     algo.save()
     algo.get_detail()
