@@ -222,7 +222,9 @@ def _create_train_task(name: str,
                        mounts: Optional[Union[Dict[str, List[Resource]], Dict[str, Resource]]]=None,
                        algorithm_git_ref: Optional[str]=None,
                        resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
-                       description: Optional[str]=None,
+                       description: Optional[str]=None,			
+                       entrypoint: Optional[str]=None,
+                       output: Optional[str]=None,
                        num_nodes: Optional[int]=1,
                        nproc_per_node: Optional[int]=1):
     resource_ids = []
@@ -246,6 +248,10 @@ def _create_train_task(name: str,
         num_nodes=num_nodes,
         nproc_per_node=nproc_per_node,
     )
+    if entrypoint is not None:
+        train_task.entrypoint = entrypoint
+    if output is not None:
+        train_task.output = output
     train_task.save()
     train_task.get_detail()
     return train_task
@@ -446,8 +452,6 @@ def quick_train(algorithm_id: Optional[str]=None,
             id=algorithm_id,
             name=algorithm_name,
             dir_path=algorithm_dir,
-            entrypoint_training=entrypoint,
-            output_training=output,
             mirror_name=mirror_name,
             uploader=resource_uploader,
             polling=resource_polling,
@@ -510,12 +514,14 @@ def quick_train(algorithm_id: Optional[str]=None,
         description=task_description,
         num_nodes=num_nodes,
         nproc_per_node=nproc_per_node,
+        entrypoint=entrypoint,
+        output=output,
     )
 
     DB().create_or_update_train_task(train_task=train_task)
     train_profile = TrainProfile(id=generate_primary_key("DESC"),
                                  train_task_id=train_task.id,
-                                 entrypoint=algo.entrypoint_training,
+                                 entrypoint=train_task.entrypoint,
                                  algorithm_id=algo.id,
                                  dataset_id=','.join([dset.id for dset in datasets]) if datasets else None,
                                  train_params=train_task.train_params,
