@@ -22,8 +22,8 @@ class Algorithm(Resource):
         算法的描述
     state
         算法状态
-    visibility 
-        算法的可见性，（默认为3）
+    public
+        算法是否公开（默认为False）
     upload_time
         算法上传时间
     filename
@@ -38,8 +38,6 @@ class Algorithm(Resource):
         算法的创建者
     node_id
         算法节点ID
-    owner
-        算法的所有者，以逗号分隔的这些用户的ID拼成的字符串，无多余空格
     tags
         算法的标签
     mirror_id
@@ -48,10 +46,6 @@ class Algorithm(Resource):
         算法的训练参数，包括数据集参数
     follows_anylearn_norm
         算法是否符合Anylearn的算法规范（默认为True）
-    entrypoint_training
-        算法训练的启动命令，非标准算法必填
-    output_training
-        算法训练结果（模型）存储目录路径，非标准算法必填
     git_address
         算法的Anylearn Gitea远端代码仓库地址
     git_migrated
@@ -69,14 +63,12 @@ class Algorithm(Resource):
         },
         # 资源创建/更新请求包体中包含的所有字段
         'payload': {
-            'create': ['name', 'description', 'visibility', 'owner',
+            'create': ['name', 'description', 'public',
                        'filename', 'tags', 'mirror_id', 'train_params',
-                       'follows_anylearn_norm',
-                       'entrypoint_training', 'output_training'],
-            'update': ['id', 'name', 'description', 'visibility', 
-                       'owner', 'tags', 'mirror_id', 'train_params',
-                       'follows_anylearn_norm',
-                       'entrypoint_training', 'output_training'],
+                       'follows_anylearn_norm'],
+            'update': ['id', 'name', 'description', 'public', 
+                       'tags', 'mirror_id', 'train_params',
+                       'follows_anylearn_norm'],
         },
     }
     """
@@ -95,7 +87,7 @@ class Algorithm(Resource):
                  name: Optional[str]=None,
                  description: Optional[str]=None,
                  state: Optional[int]=None,
-                 visibility=1,
+                 public=False,
                  upload_time: Optional[Union[datetime, str]]=None,
                  filename: Optional[str]=None,
                  is_zipfile: Optional[int]=None,
@@ -103,13 +95,10 @@ class Algorithm(Resource):
                  size: Optional[str]=None,
                  creator_id: Optional[str]=None,
                  node_id: Optional[str]=None,
-                 owner: Optional[list]=None,
                  tags: Optional[str]=None,
                  mirror_id: Optional[str]=None,
                  train_params: Optional[str]=None,
                  follows_anylearn_norm=True,
-                 entrypoint_training: Optional[str]=None,
-                 output_training: Optional[str]=None,
                  git_address: Optional[str]=None,
                  git_migrated: Optional[bool]=False,
                  load_detail=False):
@@ -124,8 +113,8 @@ class Algorithm(Resource):
             算法的描述
         state
             算法状态
-        visibility 
-            算法的可见性，（默认为1）
+        public
+            算法是否公开（默认为False）
         upload_time
             算法上传时间
         filename
@@ -140,8 +129,6 @@ class Algorithm(Resource):
             算法的创建者
         node_id
             算法节点ID
-        owner
-            算法的所有者，以逗号分隔的这些用户的ID拼成的字符串，无多余空格
         tags
             算法的标签
         mirror_id
@@ -150,10 +137,6 @@ class Algorithm(Resource):
             算法的训练参数，包括数据集参数
         follows_anylearn_norm
             算法是否符合Anylearn的算法规范（默认为True）
-        entrypoint_training
-            算法训练的启动命令，非标准算法必填
-        output_training
-            算法训练结果（模型）存储目录路径，非标准算法必填
         git_address
             算法的Anylearn Gitea远端代码仓库地址
         git_migrated
@@ -165,15 +148,13 @@ class Algorithm(Resource):
         self.mirror_id = mirror_id
         self.train_params = train_params
         self.follows_anylearn_norm = follows_anylearn_norm
-        self.entrypoint_training = entrypoint_training
-        self.output_training = output_training
         self.git_address = git_address
         self.git_migrated = git_migrated
         super().__init__(id=id, name=name, description=description,
-                         state=state, visibility=visibility,
+                         state=state, public=public,
                          upload_time=upload_time, filename=filename,
                          is_zipfile=is_zipfile, file_path=file_path, size=size,
-                         creator_id=creator_id, node_id=node_id, owner=owner,
+                         creator_id=creator_id, node_id=node_id,
                          load_detail=load_detail)
 
     def __eq__(self, other: Algorithm) -> bool:
@@ -183,7 +164,7 @@ class Algorithm(Resource):
             self.id == other.id,
             self.name == other.name,
             self.description == other.description,
-            self.visibility == other.visibility,
+            self.public == other.public,
             # self.state == other.state,
             # self.upload_time == other.upload_time,
             # self.filename == other.filename,
@@ -192,13 +173,10 @@ class Algorithm(Resource):
             # self.size == other.size,
             # self.creator_id == other.creator_id,
             # self.node_id == other.node_id,
-            # self.owner == other.owner,
             # self.tags == other.tags,
             # self.mirror_id == other.mirror_id,
             # self.train_params == other.train_params,
             self.follows_anylearn_norm == other.follows_anylearn_norm,
-            self.entrypoint_training == other.entrypoint_training,
-            self.output_training == other.output_training,
             self.git_address == other.git_address,
         ])
 
@@ -217,7 +195,7 @@ class Algorithm(Resource):
             raise AnyLearnException("请求未能得到有效响应")
         return [
             Algorithm(id=a['id'], name=a['name'], description=a['description'],
-                      state=a['state'], visibility=a['visibility'],
+                      state=a['state'], public=a['public'],
                       upload_time=a['upload_time'], tags=a['tags'],
                       follows_anylearn_norm=a['follows_anylearn_norm'],
                       git_address=a['git_address'],
@@ -244,17 +222,14 @@ class Algorithm(Resource):
         res = res[0]
         self.__init__(id=res['id'], name=res['name'],
                       description=res['description'], state=res['state'],
-                      visibility=res['visibility'],
+                      public=res['public'],
                       upload_time=res['upload_time'], filename=res['filename'],
                       is_zipfile=True if res['is_zipfile'] == 1 else False,
                       file_path=res['file'], size=res['size'],
                       creator_id=res['creator_id'], node_id=res['node_id'],
-                      owner=res['owner'], tags=res['tags'],
-                      mirror_id=res['mirror_id'],
+                      mirror_id=res['mirror_id'], tags=res['tags'],
                       train_params=res['train_params'],
                       follows_anylearn_norm=res['follows_anylearn_norm'],
-                      entrypoint_training=res['entrypoint_training'],
-                      output_training=res['output_training'],
                       git_address=res['git_address'],
                       git_migrated=res['git_migrated'])
 
@@ -270,23 +245,30 @@ class Algorithm(Resource):
     def _payload_create(self):
         payload = super()._payload_create()
         # Algorithm name verification
+        self.__validate_algo_name(payload)
+        payload['follows_anylearn_norm'] = int(payload['follows_anylearn_norm'])
+        return self.__payload_algo_params_to_str(payload)
+
+    def _payload_update(self):
+        payload = super()._payload_update()
+        # Algorithm name verification
+        self.__validate_algo_name(payload)
+        payload['follows_anylearn_norm'] = int(payload['follows_anylearn_norm'])
+        return self.__payload_algo_params_to_str(payload)
+
+    def __validate_algo_name(self, payload):
         name_pattern = re.compile(r'[a-zA-Z0-9_.-]+$')
         if not name_pattern.match(payload['name']):
             raise AnyLearnException(
                 "Algorithm name should contain only alphanumeric, dash ('-'), "
                 "underscore ('_') and dot ('.') characters"
             )
-        payload['follows_anylearn_norm'] = int(payload['follows_anylearn_norm'])
-        return self.__payload_algo_params_to_str(payload)
-
-    def _payload_update(self):
-        payload = super()._payload_update()
-        payload['follows_anylearn_norm'] = int(payload['follows_anylearn_norm'])
-        return self.__payload_algo_params_to_str(payload)
 
     def __payload_algo_params_to_str(self, payload):
         if 'train_params' in payload:
             payload['train_params'] = json.dumps(payload['train_params'])
+        if 'owner' in payload and isinstance(payload['owner'], list):
+            payload['owner'] = ",".join(payload['owner'])
         return payload
 
     @property
@@ -340,7 +322,7 @@ class Algorithm(Resource):
             name=res['name'],
             description=res['description'],
             state=res['state'],
-            visibility=res['visibility'],
+            public=res['public'],
             upload_time=res['upload_time'],
             filename=res['filename'],
             is_zipfile=True if res['is_zipfile'] == 1 else False,
@@ -348,13 +330,10 @@ class Algorithm(Resource):
             size=res['size'],
             creator_id=res['creator_id'],
             node_id=res['node_id'],
-            owner=res['owner'],
             tags=res['tags'],
             mirror_id=res['mirror_id'],
             train_params=res['train_params'],
             follows_anylearn_norm=res['follows_anylearn_norm'],
-            entrypoint_training=res['entrypoint_training'],
-            output_training=res['output_training'],
             git_address=res['git_address'],
             git_migrated=res['git_migrated'],
         )
