@@ -25,8 +25,8 @@ class Resource(BaseObject):
         资源描述（长度最大255）
     state
         资源状态
-    visibility
-        资源可见性（默认3）
+    public
+        数据集是否为公开（默认为False）
     upload_time
         资源上传时间
     filename
@@ -56,9 +56,9 @@ class Resource(BaseObject):
         },
         # 资源创建/更新请求包体中包含的所有字段
         'payload': {
-            'create': ['name', 'description', 'visibility', 'owner',
+            'create': ['name', 'description', 'public', 'owner',
                        'filename'],
-            'update': ['id', 'name', 'description', 'visibility', 'owner'],
+            'update': ['id', 'name', 'description', 'public', 'owner'],
         },
     }
 
@@ -67,7 +67,7 @@ class Resource(BaseObject):
                  name: Optional[str]=None,
                  description: Optional[str]=None,
                  state: Optional[int]=None,
-                 visibility=1,
+                 public=False,
                  upload_time: Optional[Union[datetime, str]]=None,
                  filename: Optional[str]=None,
                  is_zipfile: Optional[int]=None,
@@ -88,8 +88,8 @@ class Resource(BaseObject):
             资源描述（长度最大255）
         state
             资源状态
-        visibility
-            资源可见性（默认1）
+        public
+            数据集是否为公开（默认为False）
         upload_time
             资源上传时间
         filename
@@ -112,7 +112,7 @@ class Resource(BaseObject):
         self.name = name
         self.description = description
         self.state = state
-        self.visibility = visibility
+        self.public = public
         self.upload_time = upload_time
         self.filename = filename
         self.is_zipfile = is_zipfile
@@ -123,6 +123,16 @@ class Resource(BaseObject):
         self.owner = owner
         super().__init__(id=id, load_detail=load_detail)
 
+    def _payload_create(self):
+        payload = super()._payload_create()
+        payload['public'] = int(payload['public'])
+        return payload
+
+    def _payload_update(self):
+        payload = super()._payload_update()
+        payload['public'] = int(payload['public'])
+        return payload
+
     @classmethod
     def list_dir(cls, resource_id):
         """
@@ -241,18 +251,3 @@ class ResourceState:
     READY = 3
     DELETED = -1
     ERROR = -2
-
-
-class ResourceVisibility:
-    """
-    资源可见性标识：
-
-    - -1(HIDDEN)表示不可见
-    - 1(PRIVATE)表示仅创建者可见
-    - 2(PROTECTED)表示所有者可见
-    - 3(PUBLIC)表示公开
-    """
-    HIDDEN = -1
-    PRIVATE = 1
-    PROTECTED = 2
-    PUBLIC = 3
