@@ -94,6 +94,10 @@ class TrainTask(BaseObject):
     resource_request : :obj:`List[Dict[str, Dict[str, int]]]`, optional
         训练所需计算资源的请求。
         如未填，则使用Anylearn后端的:obj:`default`资源组中的默认资源套餐。
+    entrypoint
+        算法训练的启动命令，非标准算法必填
+    output
+        算法训练结果（模型）存储目录路径，非标准算法必填
     """
 
     _fields = {
@@ -106,7 +110,8 @@ class TrainTask(BaseObject):
         'payload': {
             'create': ['name', 'description', 'project_id', 'algorithm_id',
                        'algorithm_git_ref', 'train_params', 'envs',
-                       'files', 'resource_request', 'num_nodes', 'nproc_per_node'],
+                       'files', 'resource_request', 'num_nodes', 'nproc_per_node',
+                       'entrypoint', 'output'],
             'update': [],
         },
     }
@@ -138,6 +143,8 @@ class TrainTask(BaseObject):
                  final_metric: Optional[float]=None,
                  resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
                  load_detail=False,
+                 entrypoint: Optional[str]=None,
+                 output: Optional[str]=None,
                  num_nodes=1,
                  nproc_per_node=1):
         """
@@ -186,6 +193,10 @@ class TrainTask(BaseObject):
             初始化时是否加载详情
         num_nodes
             训练任务请求的节点数
+        entrypoint
+            算法训练的启动命令，非标准算法必填
+        output
+            算法训练结果（模型）存储目录路径，非标准算法必填
         """
         self.name = name
         self.description = description
@@ -207,6 +218,8 @@ class TrainTask(BaseObject):
         self.resource_request = resource_request
         self.num_nodes = num_nodes
         self.nproc_per_node = nproc_per_node
+        self.entrypoint = entrypoint
+        self.output = output
         super().__init__(id=id, load_detail=load_detail)
 
     def finished(self):
@@ -260,6 +273,8 @@ class TrainTask(BaseObject):
                       secret_key=res['secret_key'],
                       create_time=res['create_time'],
                       finish_time=res['finish_time'],
+                      entrypoint=res['entrypoint'],
+                      output=res['output'],
                       envs=res['envs'],
                       resource_request=json.loads(res['resource_request']))
 
