@@ -92,8 +92,6 @@ class TestQuickTrain(BaseTestCase):
                           'train_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR002",
                           'follows_anylearn_norm': False,
-                          'entrypoint_training': "python train.py",
-                          'output_training': "output",
                           'git_address': "http://anylearn.testing/anylearn/Test-Algo_1.1.git",
                           'git_migrated': True,
                       }],
@@ -138,6 +136,8 @@ class TestQuickTrain(BaseTestCase):
                           'finish_time': "",
                           'envs': "",
                           'resource_request': '[{"default": {"CPU": 1}}]',
+                          'entrypoint': "python train.py",
+                          'output': "output",
                       }],
                       status=200)
 
@@ -298,8 +298,6 @@ class TestQuickTrain(BaseTestCase):
                           'train_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR002",
                           'follows_anylearn_norm': False,
-                          'entrypoint_training': "python train.py",
-                          'output_training': "output",
                           'git_address': "http://anylearn.testing/anylearn/TestAlgo1.git",
                           'git_migrated': True,
                       }],
@@ -402,8 +400,6 @@ class TestQuickTrain(BaseTestCase):
                           'train_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR002",
                           'follows_anylearn_norm': False,
-                          'entrypoint_training': "python train.py",
-                          'output_training': "output",
                           'git_address': "http://anylearn.testing/anylearn/TestAlgo1.git",
                           'git_migrated': True,
                       }],
