@@ -2,7 +2,7 @@ import responses
 from requests.exceptions import RequestException
 
 from anylearn.config import init_sdk
-from anylearn.interfaces.resource.resource import ResourceState, ResourceVisibility
+from anylearn.interfaces.resource.resource import ResourceState
 from anylearn.interfaces.resource.algorithm import Algorithm
 from anylearn.utils.errors import AnyLearnException, AnyLearnMissingParamException
 from tests.base_test_case import BaseTestCase
@@ -17,7 +17,7 @@ class TestAlgorithm(BaseTestCase):
                               'name': "TestAlgo1",
                               'description': "test",
                               'state': ResourceState.READY,
-                              'visibility': ResourceVisibility.PUBLIC,
+                              'public': False,
                               'upload_time': "2020-01-01 00:00",
                               'tags': "tag1, tag2",
                               'follows_anylearn_norm': True,
@@ -29,7 +29,7 @@ class TestAlgorithm(BaseTestCase):
                               'name': "TestAlgo2",
                               'description': "test",
                               'state': ResourceState.READY,
-                              'visibility': ResourceVisibility.PUBLIC,
+                              'public': True,
                               'upload_time': "2020-01-02 00:00",
                               'tags': "tag3, tag4",
                               'follows_anylearn_norm': False,
@@ -69,7 +69,7 @@ class TestAlgorithm(BaseTestCase):
                           'name': "TestAlgo1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "test.tar.gz",
                           'is_zipfile': 1,
@@ -77,13 +77,10 @@ class TestAlgorithm(BaseTestCase):
                           'size': "250.41",
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                           'tags': "tag1, tag2",
                           'train_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR001",
                           'follows_anylearn_norm': True,
-                          'entrypoint_training': "python train.py",
-                          'output_training': "output",
                           'git_address': "http://anylearn.testing/user001/TestAlgo1.git",
                           'git_migrated': True,
                       }],
@@ -96,15 +93,11 @@ class TestAlgorithm(BaseTestCase):
         self.assertEqual(algo.size, "250.41")
         self.assertEqual(algo.creator_id, "USER001")
         self.assertEqual(algo.node_id, "NODE001")
-        self.assertIsInstance(algo.owner, list)
-        self.assertEqual(algo.owner[0], "USER001")
         self.assertEqual(algo.tags, "tag1, tag2")
         self.assertIsInstance(algo.train_params, list)
         self.assertEqual(str(algo.train_params), "[{'test': 'test'}]")
         self.assertEqual(algo.mirror_id, "MIRR001")
         self.assertEqual(algo.follows_anylearn_norm, True)
-        self.assertEqual(algo.entrypoint_training, "python train.py")
-        self.assertEqual(algo.output_training, "output")
 
     @responses.activate
     def test_get_algo_detail_no_explicit_call_ok(self):
@@ -114,7 +107,7 @@ class TestAlgorithm(BaseTestCase):
                           'name': "TestAlgo1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "test.tar.gz",
                           'is_zipfile': 1,
@@ -122,13 +115,10 @@ class TestAlgorithm(BaseTestCase):
                           'size': "250.41",
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                           'tags': "tag1, tag2",
                           'train_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR001",
                           'follows_anylearn_norm': False,
-                          'entrypoint_training': "python niart.py",
-                          'output_training': "tuptuo",
                           'git_address': "http://anylearn.testing/user001/TestAlgo1.git",
                           'git_migrated': True,
                       }],
@@ -141,15 +131,11 @@ class TestAlgorithm(BaseTestCase):
         self.assertEqual(algo.size, "250.41")
         self.assertEqual(algo.creator_id, "USER001")
         self.assertEqual(algo.node_id, "NODE001")
-        self.assertIsInstance(algo.owner, list)
-        self.assertEqual(algo.owner[0], "USER001")
         self.assertEqual(algo.tags, "tag1, tag2")
         self.assertIsInstance(algo.train_params, list)
         self.assertEqual(str(algo.train_params), "[{'test': 'test'}]")
         self.assertEqual(algo.mirror_id, "MIRR001")
         self.assertEqual(algo.follows_anylearn_norm, False)
-        self.assertEqual(algo.entrypoint_training, "python niart.py")
-        self.assertEqual(algo.output_training, "tuptuo")
 
     @responses.activate
     def test_get_algo_detail_ko_403(self):
@@ -249,11 +235,25 @@ class TestAlgorithm(BaseTestCase):
                       status=200)
         algo = Algorithm(id="ALGO001", name="TestAlgo1", description="test m",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PUBLIC,
+                          public=True,
                           upload_time="2020-01-01 00:00")
         result = algo.save()
         self.assertTrue(result)
 
+    def test_update_algo_name_not_standard(self):
+        with self.assertRaises(AnyLearnException) as ctx:
+            algo = Algorithm(id="ALGO123",
+                             name="Test@ALGO/001",
+                             filename="test.tar.gz",
+                             mirror_id="MIRR001")
+            algo.save()
+        e = ctx.exception
+        self.assertIsInstance(e, AnyLearnException)
+        self.assertEqual(
+            e.msg,
+            "Algorithm name should contain only alphanumeric, dash ('-'), underscore ('_') and dot ('.') characters"
+        )
+
     @responses.activate
     def test_update_algo_ko_empty_name(self):
         algo = Algorithm(id="ALGO250", name="")
@@ -270,7 +270,7 @@ class TestAlgorithm(BaseTestCase):
                       status=200)
         algo = Algorithm(id="ALGO250", name="TestAlgo", description="test",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PROTECTED,
+                          public=False,
                           upload_time="2020-01-01 02:50")
         with self.assertRaises(AnyLearnException) as ctx:
             algo.save()
@@ -287,7 +287,7 @@ class TestAlgorithm(BaseTestCase):
                       status=200)
         algo = Algorithm(id="ALGO001", name="TestAlgo1", description="test d",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PUBLIC,
+                          public=True,
                           upload_time="2020-01-01 00:00")
         result = algo.delete()
         self.assertTrue(result)
@@ -301,7 +301,7 @@ class TestAlgorithm(BaseTestCase):
                       status=204)
         algo = Algorithm(id="ALGO250", name="TestAlgo", description="test",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PROTECTED,
+                          public=False,
                           upload_time="2020-01-01 02:50")
         with self.assertRaises(AnyLearnException) as ctx:
             algo.delete()
