@@ -2,7 +2,7 @@ import responses
 from requests.exceptions import RequestException
 
 from anylearn.config import init_sdk
-from anylearn.interfaces.resource.resource import ResourceState, ResourceVisibility
+from anylearn.interfaces.resource.resource import ResourceState
 from anylearn.interfaces.resource.dataset import Dataset
 from anylearn.utils.errors import AnyLearnException, AnyLearnMissingParamException
 from tests.base_test_case import BaseTestCase
@@ -17,7 +17,7 @@ class TestDataset(BaseTestCase):
                               'name': "TestDset1",
                               'description': "test",
                               'state': ResourceState.READY,
-                              'visibility': ResourceVisibility.PUBLIC,
+                              'public': False,
                               'upload_time': "2020-01-01 00:00",
                           },
                           {
@@ -25,7 +25,7 @@ class TestDataset(BaseTestCase):
                               'name': "TestDset2",
                               'description': "test",
                               'state': ResourceState.READY,
-                              'visibility': ResourceVisibility.PUBLIC,
+                              'public': True,
                               'upload_time': "2020-01-02 00:00",
                           },
                       ],
@@ -57,7 +57,7 @@ class TestDataset(BaseTestCase):
                           'name': "TestDset1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "test.tar.gz",
                           'is_zipfile': 1,
@@ -65,12 +65,11 @@ class TestDataset(BaseTestCase):
                           'size': "250.41",
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                       }],
                       status=200)
         dataset = Dataset(id="DSET001", name="TestDset1", description="test",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PUBLIC,
+                          public=True,
                           upload_time="2020-01-01 00:00")
         dataset.get_detail()
         self.assertEqual(dataset.filename, "test.tar.gz")
@@ -79,8 +78,6 @@ class TestDataset(BaseTestCase):
         self.assertEqual(dataset.size, "250.41")
         self.assertEqual(dataset.creator_id, "USER001")
         self.assertEqual(dataset.node_id, "NODE001")
-        self.assertIsInstance(dataset.owner, list)
-        self.assertEqual(dataset.owner[0], "USER001")
 
 
     @responses.activate
@@ -91,7 +88,7 @@ class TestDataset(BaseTestCase):
                           'name': "TestDset1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "test.tar.gz",
                           'is_zipfile': 1,
@@ -99,7 +96,6 @@ class TestDataset(BaseTestCase):
                           'size': "250.41",
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                       }],
                       status=200)
         dataset = Dataset(id="DSET001", load_detail=True)
@@ -110,8 +106,6 @@ class TestDataset(BaseTestCase):
         self.assertEqual(dataset.size, "250.41")
         self.assertEqual(dataset.creator_id, "USER001")
         self.assertEqual(dataset.node_id, "NODE001")
-        self.assertIsInstance(dataset.owner, list)
-        self.assertEqual(dataset.owner[0], "USER001")
 
     @responses.activate
     def test_get_dataset_detail_ko_403(self):
@@ -120,7 +114,7 @@ class TestDataset(BaseTestCase):
         dataset = Dataset(id="DSET403", name="TestDsetForbidden",
                           description="test",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PRIVATE,
+                          public=False,
                           upload_time="2020-04-03 04:03")
         with self.assertRaises(RequestException) as ctx:
             dataset.get_detail()
@@ -135,7 +129,7 @@ class TestDataset(BaseTestCase):
                       status=200)
         dataset = Dataset(id="DSET250", name="TestDset", description="test",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PROTECTED,
+                          public=False,
                           upload_time="2020-01-01 02:50")
         with self.assertRaises(AnyLearnException) as ctx:
             dataset.get_detail()
@@ -150,7 +144,7 @@ class TestDataset(BaseTestCase):
                       status=200)
         dataset = Dataset(id="DSET250", name="TestDset", description="test",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PROTECTED,
+                          public=False,
                           upload_time="2020-01-01 02:50")
         with self.assertRaises(AnyLearnException) as ctx:
             dataset.get_detail()
@@ -195,7 +189,7 @@ class TestDataset(BaseTestCase):
                       status=200)
         dataset = Dataset(id="DSET001", name="TestDset1", description="test m",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PUBLIC,
+                          public=True,
                           upload_time="2020-01-01 00:00")
         result = dataset.save()
         self.assertTrue(result)
@@ -216,7 +210,7 @@ class TestDataset(BaseTestCase):
                       status=200)
         dataset = Dataset(id="DSET250", name="TestDset", description="test",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PROTECTED,
+                          public=False,
                           upload_time="2020-01-01 02:50")
         with self.assertRaises(AnyLearnException) as ctx:
             dataset.save()
@@ -233,7 +227,7 @@ class TestDataset(BaseTestCase):
                       status=200)
         dataset = Dataset(id="DSET001", name="TestDset1", description="test d",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PUBLIC,
+                          public=True,
                           upload_time="2020-01-01 00:00")
         result = dataset.delete()
         self.assertTrue(result)
@@ -247,7 +241,7 @@ class TestDataset(BaseTestCase):
                       status=204)
         dataset = Dataset(id="DSET250", name="TestDset", description="test",
                           state=ResourceState.READY,
-                          visibility=ResourceVisibility.PROTECTED,
+                          public=False,
                           upload_time="2020-01-01 02:50")
         with self.assertRaises(AnyLearnException) as ctx:
             dataset.delete()
