@@ -35,6 +35,8 @@ class TestTrainTask(BaseTestCase):
                           'finish_time': "",
                           'envs': "",
                           'resource_request': '[{"default": {"CPU": 1}}]',
+                          'entrypoint': "python train.py",
+                          'output': "output",
                       }],
                       status=200)
         train_task = TrainTask(id="TRAI001")
@@ -72,6 +74,8 @@ class TestTrainTask(BaseTestCase):
                           'finish_time': "",
                           'envs': "",
                           'resource_request': '[{"default": {"CPU": 1}}]',
+                          'entrypoint': "python train.py",
+                          'output': "output",
                       }],
                       status=200)
         train_task = TrainTask(id="TRAI002", load_detail=True)
@@ -668,7 +672,7 @@ class TestTrainTask(BaseTestCase):
         DB().create_or_update_train_task(train_task=test_train_task)
         train_profile = TrainProfile(id=uuid.uuid1().__str__(),
                                      train_task_id=test_train_task.id,
-                                     entrypoint="algo.entrypoint_training",
+                                     entrypoint="train_task.entrypoint",
                                      algorithm_id="algo.id",
                                      dataset_id="dset.id",
                                      train_params="train_task.train_params",
